
# Type: sex qualifier


a qualifier used in a phenotypic association to state whether the association is specific to a particular sex.

URI: [biolink:sex_qualifier](https://w3id.org/biolink/vocab/sex_qualifier)


## Domain and Range

[Association](Association.md) ->  <sub>OPT</sub> [BiologicalSex](BiologicalSex.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children


## Used by

 * [CaseToPhenotypicFeatureAssociation](CaseToPhenotypicFeatureAssociation.md)
 * [DiseaseToPhenotypicFeatureAssociation](DiseaseToPhenotypicFeatureAssociation.md)
 * [EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md)
 * [ExposureEventToPhenotypicFeatureAssociation](ExposureEventToPhenotypicFeatureAssociation.md)
 * [GeneToPhenotypicFeatureAssociation](GeneToPhenotypicFeatureAssociation.md)
 * [GenotypeToPhenotypicFeatureAssociation](GenotypeToPhenotypicFeatureAssociation.md)
 * [VariantToPhenotypicFeatureAssociation](VariantToPhenotypicFeatureAssociation.md)
